# YengaPay Plugin for PrestaShop

A PrestaShop module that integrates YengaPay payment gateway, allowing customers to pay using local mobile money payment systems and other supported payment methods.

## Features

- **Easy Integration**: Seamlessly integrates with PrestaShop 1.7.6.0 and above
- **Mobile Money Payments**: Supports payments via mobile money and other local payment methods
- **Real-Time Notifications**: Automatically updates order statuses using webhooks
- **Secure Payments**: Uses HMAC-SHA256 to validate webhook requests
- **Customizable**: Allows merchants to configure API keys, project IDs, and webhook settings
- **Multi-Currency Support**: Handles payments in multiple currencies with automatic conversion
- **Order Management**: Updates order statuses based on payment status (e.g., Paid, Failed, Pending, Cancelled)

## Requirements

- **PrestaShop Version**: 1.7.6.0 or higher
- **PHP Version**: 7.2 or higher
- **SSL Certificate**: Required for secure transactions
- **YengaPay Account**: A valid YengaPay merchant account with API credentials

## Installation

### Download the Module

1. Download the module as a .zip file from the repository or your source.

### Install via PrestaShop Admin

1. Log in to your PrestaShop admin panel.
2. Go to Modules > Module Manager.
3. Click on Upload a Module and select the downloaded .zip file.
4. Click Install.

### Configure the Module

1. After installation, go to Modules > Module Manager.
2. Find YengaPay in the list and click Configure.
3. Enter your Group ID, API Key, Project ID, and Webhook Secret.
4. Save the settings.

### Set Up Webhooks

1. Copy the Webhook URL provided in the module configuration.
2. Log in to your YengaPay dashboard and add the webhook URL.
3. Ensure the Webhook Secret matches the one in your YengaPay dashboard.

## Configuration

### Module Settings

- **Group ID**: Your YengaPay Group ID (provided by YengaPay)
- **Project ID**: Your YengaPay Project ID (provided by YengaPay)
- **API Key**: Your YengaPay API Key (provided by YengaPay)
- **Webhook Secret**: A secret key used to validate webhook requests (must match the one in your YengaPay dashboard)
- **Webhook URL**: Automatically generated by the module. Copy this URL to your YengaPay dashboard.

## Payment Flow

1. **Checkout**: Customers select YengaPay as the payment method during checkout.
2. **Payment**: Customers are redirected to YengaPay's payment page to complete the transaction.
3. **Order Status**: The order status is updated automatically based on the payment status:
   - `DONE`: Payment successful (Order status: "Payment Accepted")
   - `FAILED`: Payment failed (Order status: "Payment Error")
   - `PENDING`: Payment pending (Order status: "Waiting for Payment")
   - `CANCELLED`: Payment cancelled (Order status: "Cancelled")

## Testing

1. Enable Test Mode: Use YengaPay's sandbox environment for testing.
2. Create a Test Order: Add a product to the cart and proceed to checkout.
3. Select YengaPay as the payment method.
4. Complete Payment using test credentials.
5. Check Order Status to verify correct updates.

## Troubleshooting

### Common Issues

- **Payment Not Processing**:
  - Verify API credentials (Group ID, Project ID, API Key)
  - Ensure a valid SSL certificate is installed

- **Webhook Not Working**:
  - Check webhook URL configuration in YengaPay dashboard
  - Ensure Webhook Secret matches in module and dashboard
  - Verify server allows incoming webhook requests

- **Order Status Not Updating**:
  - Check PrestaShop logs for YengaPay-related errors
  - Verify webhook is receiving and processing payment notifications

## Support

- **YengaPay Support**: support@yengapay.com
- **Developer**: Kreezus
- **Documentation**: [YengaPay Documentation](https://yengapay.com/)

## License

This module is released under the Academic Free License 3.0 (AFL-3.0). See LICENSE.md for details.

## Credits

- **Developer**: Kreezus
- **YengaPay Team**: For providing the API and support
- **PrestaShop Community**: For the PrestaShop platform

## Changelog

### v1.0.0 (Initial Release)
- Initial release of the YengaPay module for PrestaShop
- Supports mobile money payments, webhook integration, and order status updates